@@ -6,12 +6,17 @@ import pytest
 
 @pytest.fixture(scope="session")
 def TEST_SUPERMETRICS_FILE_PATH():
-    return "/home/viadot/tests/integration/test_supermetrics.csv"
+    return "test_supermetrics.csv"
 
 
 @pytest.fixture(scope="session")
 def TEST_CSV_FILE_PATH():
-    return "/home/viadot/tests/test_data_countries.csv"
+    return "test_data_countries.csv"
+
+
+@pytest.fixture(scope="session")
+def TEST_PARQUET_FILE_PATH():
+    return "test_data_countries.parquet"
 
 
 @pytest.fixture(scope="session")
@@ -29,6 +34,13 @@ def DF():
 
 @pytest.fixture(scope="session", autouse=True)
 def create_test_csv_file(DF, TEST_CSV_FILE_PATH):
-    DF.to_csv(TEST_CSV_FILE_PATH, index=False)
+    DF.to_csv(TEST_CSV_FILE_PATH, index=False, sep="\t")
     yield
     os.remove(TEST_CSV_FILE_PATH)
+
+
+@pytest.fixture(scope="session", autouse=True)
+def create_test_parquet_file(DF, TEST_PARQUET_FILE_PATH):
+    DF.to_parquet(TEST_PARQUET_FILE_PATH, index=False)
+    yield
+    os.remove(TEST_PARQUET_FILE_PATH)
