@@ -1,23 +1,22 @@
+import json
 import os
 from typing import Any, Dict, List
-import json
-from viadot.tasks.azure_data_lake import AzureDataLakeDownload
+
 import pandas as pd
-
-
-from prefect import Flow, task, Parameter
+from prefect import Flow, Parameter, task
+from prefect.backend import get_key_value
 from prefect.storage import Local
 from prefect.utilities import logging
-from prefect.backend import get_key_value
+
+from viadot.tasks.azure_data_lake import AzureDataLakeDownload
 
 from ..tasks import (
+    AzureDataLakeCopy,
     AzureDataLakeToDF,
     AzureDataLakeUpload,
     AzureSQLCreateTable,
     BCPTask,
     DownloadGitHubFile,
-    AzureDataLakeToDF,
-    AzureDataLakeCopy,
 )
 
 logger = logging.get_logger(__name__)
@@ -75,11 +74,6 @@ def df_to_csv_task(df, path: str, sep: str = "\t"):
     df.to_csv(path, sep=sep, index=False)
 
 
-@task
-def is_stored_locally(f: Flow):
-    return f.storage is None or isinstance(f.storage, Local)
-
-
 class ADLSToAzureSQL(Flow):
     def __init__(
         self,
@@ -90,6 +84,7 @@ class ADLSToAzureSQL(Flow):
         overwrite_adls: bool = True,
         if_empty: str = "warn",
         adls_sp_credentials_secret: str = None,
+        dtypes: Dict[str, Any] = None,
         table: str = None,
         schema: str = None,
         if_exists: str = "replace",  # this applies to the full CSV file, not per chunk
@@ -116,6 +111,8 @@ class ADLSToAzureSQL(Flow):
             adls_sp_credentials_secret (str, optional): The name of the Azure Key Vault secret containing a dictionary with
             ACCOUNT_NAME and Service Principal credentials (TENANT_ID, CLIENT_ID, CLIENT_SECRET) for the Azure Data Lake.
             Defaults to None.
+            dtypes (dict, optional): Which custom data types should be used for SQL table creation task.
+            To be used only in case that dtypes need to be manually mapped - dtypes from raw schema file in use by default. Defaults to None.
             table (str, optional): Destination table. Defaults to None.
             schema (str, optional): Destination schema. Defaults to None.
             if_exists (str, optional): What to do if the table exists. Defaults to "replace".
@@ -134,6 +131,7 @@ class ADLSToAzureSQL(Flow):
             self.adls_path = get_key_value(key=adls_path)
 
         # Read schema info json from RAW
+        self.dtypes = dtypes
         self.adls_root_dir_path = os.path.split(self.adls_path)[0]
         self.adls_file_name = os.path.split(self.adls_path)[-1]
         extension = os.path.splitext(self.adls_path)[-1]
@@ -190,10 +188,23 @@ class ADLSToAzureSQL(Flow):
 
     def gen_flow(self) -> Flow:
         adls_raw_file_path = Parameter("adls_raw_file_path", default=self.adls_path)
+        df = lake_to_df_task.bind(
+            path=adls_raw_file_path,
+            sp_credentials_secret=self.adls_sp_credentials_secret,
+            flow=self,
+        )
 
-        df = lake_to_df_task.bind(path=adls_raw_file_path, flow=self)
-
-        dtypes = map_data_types_task.bind(self.local_json_path, flow=self)
+        if not self.dtypes:
+            download_json_file_task.bind(
+                from_path=self.json_shema_path,
+                to_path=self.local_json_path,
+                sp_credentials_secret=self.adls_sp_credentials_secret,
+                flow=self,
+            )
+            dtypes = map_data_types_task.bind(self.local_json_path, flow=self)
+            map_data_types_task.set_upstream(download_json_file_task, flow=self)
+        else:
+            dtypes = self.dtypes
 
         df_to_csv = df_to_csv_task.bind(
             df=df,
@@ -201,7 +212,6 @@ class ADLSToAzureSQL(Flow):
             sep=self.sep,
             flow=self,
         )
-
         promote_to_conformed_task.bind(
             from_path=self.local_file_path,
             to_path=self.adls_path_conformed,
@@ -217,12 +227,6 @@ class ADLSToAzureSQL(Flow):
             vault_name=self.vault_name,
             flow=self,
         )
-        download_json_file_task.bind(
-            from_path=self.json_shema_path,
-            to_path=self.local_json_path,
-            flow=self,
-        )
-
         create_table_task.bind(
             schema=self.schema,
             table=self.table,
@@ -241,9 +245,9 @@ class ADLSToAzureSQL(Flow):
             flow=self,
         )
 
-        dtypes.set_upstream(download_json_file_task, flow=self)
+        # dtypes.set_upstream(download_json_file_task, flow=self)
         promote_to_conformed_task.set_upstream(df_to_csv, flow=self)
-        map_data_types_task.set_upstream(lake_to_df_task, flow=self)
+        # map_data_types_task.set_upstream(download_json_file_task, flow=self)
         create_table_task.set_upstream(df_to_csv, flow=self)
         promote_to_operations_task.set_upstream(promote_to_conformed_task, flow=self)
         bulk_insert_task.set_upstream(create_table_task, flow=self)
